#
# spec file for package ceph-csi
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ceph-csi
Version:        1.2.2+git0.gf8c854dc
Release:        lp152.1.4
Summary:        Container Storage Interface driver for Ceph block and file
License:        Apache-2.0
URL:            https://github.com/ceph/ceph-csi

Source0:        %{name}-%{version}.tar.xz
Source98:       README
Source99:       update-tarball.sh

%if 0%{?suse_version}
# _insert_obs_source_lines_here
ExclusiveArch:  x86_64 aarch64 ppc64 ppc64le
%endif

# Go and spec requirements
BuildRequires:  go
BuildRequires:  golang-packaging
BuildRequires:  xz

# Rook runtime requirements - referenced from packages installed in Rook images
# From Ceph base container: github.com/ceph/ceph-container/src/daemon-base/...
Requires:       pattern() = ceph_base

%description
Ceph CSI plugins implement an interface between CSI enabled Container
Orchestrator (CO) and Ceph cluster. It allows dynamically provisioning
Ceph block and file volumes and attaching them to workloads.

See https://github.com/ceph/ceph-csi for more information.

################################################################################
# The tasty, meaty build section
################################################################################

%define _buildshell /bin/bash

%{go_nostrip}
%{go_provides}

%prep
%setup -q -n %{name}

%build
%goprep github.com/ceph/ceph-csi
export CGO_ENABLED=0

# Make sure version contains parseable symbols
version_parsed=%{version}
version_parsed="${version_parsed//[+]/-}"
git_commit_parsed="$(echo $version_parsed | sed 's/.*\.g\(.*\).*/\1/')"
linker_flags=(
    "-X" "github.com/ceph/ceph-csi/pkg/util.GitCommit=$git_commit_parsed"
    "-X" "github.com/ceph/ceph-csi/pkg/util.DriverVersion=$version_parsed"
)
build_flags=("-ldflags" "${linker_flags[*]}")

# builds a binary called 'cmd'
%gobuild "${build_flags[@]}" cmd

%install

bin_location=%{_builddir}/go/bin/
install_location=%{buildroot}%{_bindir}

install --mode=755 --directory "${install_location}"

mv ${bin_location}/cmd ${bin_location}/cephcsi
install --preserve-timestamps --mode=755 --target-directory="${install_location}" "${bin_location}"/cephcsi

################################################################################
# Specify which files we built belong to each package
################################################################################
# ceph-csi.arch.rpm
%files
%defattr(-,root,root,-)
%{_bindir}/cephcsi

################################################################################
# Finalize
################################################################################

# ceph-csi RPMs aren't for users to install, just to be put in containers, so
# don't bother adding docs or changelog or anything

%changelog
* Tue Dec  3 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Update to v1.2.2:
  * Add kernel version detection for mounting with client
  * Fix issue in helm chat pushing
  * Added forcecephkernelclient as startup parameter to force enabling ceph
  * Handle EACCESS error from 'ceph rbd task add remove'
  * Fix vol size for cephfs and rbd
  * Update registration directory name
  * Reorder kernel version checking logic
  * Increase sidecar time out value to 150s.
  * Format ext4 with lazy_journal_init
  * Change default csi liveness ports to ones less common
  * Add POD_NAMESPACE to RBD provisioner deployments
  * Add a check for nil secrets
  * Remove rootfs from rbd provisioner pod
  * Added E2E for rbd nodeplugin restart
  * Deprecate containerized flag and remove nsenter
- Update to v1.2.1:
  * Change the recommended/default FS for RBD to ext4
  * Use nodiscard option while formatting RBD devices.
  * Use provisioner socket while probing liveness.
  * Reject request if the operation is in progress
  * Fix pod termination issue due to stale mount after node plugin restart.
- Remove patch (merged upstream):
  * 0001-Added-forcecephkernelclient-as-startup-parameter-to-.patch
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Oct  2 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Set Version when building (bsc#1152690)
* Tue Oct  1 2019 Stefan Haas <stefan.haas@suse.com>
- Add forcecephkernelclient as startup parameter (bsc#1152690)
  * Add 0001-Added-forcecephkernelclient-as-startup-parameter-to-.patch
* Mon Sep  9 2019 Blaine Gardner <blaine.gardner@suse.com>
- Update to release v1.2.0 (bsc#1151479)
  + Cephfs: Use ceph kernel client if kernel version >= 4.17
  + implement grpc metrics for ceph-csi
  + Add xfs fstype as default type in storageclass
  + Add support to use ceph manager rbd command to delete an image
  + e2e: correct log format in execCommandInPod()
  + Add 'gosec' to the static-checks
  + switch to cephfs, utils, and csicommon to new loging system
  + utility to trace backend volume from RBD pvc
  + Implement context-based logging
  + implement klog wrapper
  + unmap rbd image if connection timeout.
  + start controller or node server based on config
  + fix: Adds liveness sidecar to v1.14+ helm charts
  + Prometheus liveness probe sidecar
  + Wrap error if failed to fetch mon
  + provisioners: add reconfiguring of PID limit
  + Use "rbd device list" to list and find rbd images and their device paths
  + Update Unstage transaction to undo steps done in Stage
  + Move mounting staging instance to a sub-path within staging path
  + e2e: do not fail to delete resources when "resource not found"
  + remove post validation of rbd device
* Tue Aug 13 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Tech preview release for containers (bsc#1145433)
* Wed Jul 17 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Use ceph-base pattern instead of individual packages
* Fri Jul 12 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Updating to the v1.1.0
  + CephFS subvolume/manager based volume provisioning and deletion.
  + E2E test support for PVC creation, App pod mounting.etc.
  + CSI spec v1.1 support
  + Kube dependency updated to 1.15.
  + Configuration store change from configmap to rados omap
  + Mount options support for CephFS and RBD volumes
  + Move locks to more granular locking than CPU count based
  + Rbd support for ReadWriteMany PVCs for block mode
  + Unary plugin code for both ( CephFS and RBD ) drivers.
  + Driver name updated to CSI spec standard.
  + helm chart updates.
  + sidecar updates to latest available.
  + RBAC corrections and updates for containers.
  + Lock protection for create,delete volume ..etc operations
  + Added CSIDriver CRD.
* Fri Jul 12 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update version to be parsed by OBS service
* Thu Jul 11 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update version according to openSUSE package name guidelines
* Mon Jul  8 2019 Blaine Gardner <blaine.gardner@suse.com>
- Initial submission
- Build from upstream github.com/ceph/ceph-csi initially
  + Initially use master branch
- Version at commit fa68c35f3b5d9081d8aa3241baf71064af967aa9
